Affected by GO-2024-2993
and 3 other vulnerabilities
GO-2024-2993: Sliver Allows Authenticated Operator-to-Server Remote Code Execution in github.com/bishopfox/sliver
GO-2026-4280: Sliver Vulnerable to Pre-Auth Memory Exhaustion via NoEncoder Bypass in github.com/bishopfox/sliver
GO-2026-4445: Sliver Vulnerable to Website Path Traversal / Arbitrary File Read (Authenticated) in github.com/bishopfox/sliver
GO-2026-4466: Sliver has DNS C2 OTP Bypass that Allows Unauthenticated Session Flooding and Denial of Service in github.com/bishopfox/sliver
package
Version:
v1.6.4
Opens a new window with list of versions in this module.
Published: Jan 15, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 27
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
client/command/update
Overview
Implements the 'update' command group for the Sliver client console.
Go Files
commands.go – Registers the update command for checking new releases.
update.go – Contacts the update endpoint and reports available client/server versions.
Documentation
¶
func Commands ¶
added in
v1.6.0
Commands returns the “ command and its subcommands.
UpdateCmd - Check for updates.
VerboseVersionsCmd - Get verbose version information about the client and server.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.