Affected by GO-2025-4079
and 3 other vulnerabilities
GO-2025-4079: Silver has unrestricted traffic between Wireguard clients in github.com/bishopfox/sliver
GO-2026-4445: Sliver Vulnerable to Website Path Traversal / Arbitrary File Read (Authenticated) in github.com/bishopfox/sliver
GO-2026-4466: Sliver has DNS C2 OTP Bypass that Allows Unauthenticated Session Flooding and Denial of Service in github.com/bishopfox/sliver
GO-2026-4548: Sliver has Potential Zip Bomb Denial of Service in GzipEncoder in github.com/bishopfox/sliver
package
Version:
v1.4.21
Opens a new window with list of versions in this module.
Published: Aug 26, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 4
Opens a new window with list of known importers.
README
¶
Handlers
WARNING: Methods in this package can be invoked by a Sliver without user-interaction (e.g. they're publically invokable)
The handlers package contains backend APIs that can be directly invoked by a remote sliver without a corrisponding protobuf request.
Documentation
¶
func AddSessionHandlers(key uint32, value interface{})
AddSessionHandlers - Adds a new handler to the map of server-side msg handlers
func GetSessionHandlers() map[uint32]interface{}
GetSessionHandlers - Returns a map of server-side msg handlers
Source Files
¶
Click to show internal directories.
Click to hide internal directories.