Affected by GO-2023-1866
and 6 other vulnerabilities
GO-2023-1866: Silver vulnerable to MitM attack against implants due to a cryptography vulnerability in github.com/bishopfox/sliver
GO-2025-3472: SSRF in sliver teamserver in github.com/bishopfox/sliver
GO-2025-4079: Silver has unrestricted traffic between Wireguard clients in github.com/bishopfox/sliver
GO-2026-4280: Sliver Vulnerable to Pre-Auth Memory Exhaustion via NoEncoder Bypass in github.com/bishopfox/sliver
GO-2026-4445: Sliver Vulnerable to Website Path Traversal / Arbitrary File Read (Authenticated) in github.com/bishopfox/sliver
GO-2026-4466: Sliver has DNS C2 OTP Bypass that Allows Unauthenticated Session Flooding and Denial of Service in github.com/bishopfox/sliver
GO-2026-4548: Sliver has Potential Zip Bomb Denial of Service in GzipEncoder in github.com/bishopfox/sliver
package
Version:
v1.5.35
Opens a new window with list of versions in this module.
Published: Mar 5, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 10
Opens a new window with list of known importers.
README
¶
Website
This package manages static content that can be hosted on HTTP(S) C2 domains to make them look more legit.
Documentation
¶
-
func AddContent(websiteName string, path string, contentType string, content []byte) error
-
func AddWebsite(websiteName string) (*models.Website, error)
-
func GetContent(websiteName string, path string) (string, []byte, error)
-
func MapContent(websiteName string, eagerLoadContents bool) (*clientpb.Website, error)
-
func Names() ([]string, error)
-
func RemoveContent(websiteName string, path string) error
AddContent - Add website content for a path
AddWebsite - Add website with no content
GetContent - Get static content for a given path
MapContent - List the content of a specific site, returns map of path->json(content-type/size)
Names - List all websites
RemoveContent - Remove website content for a path
Source Files
¶
Click to show internal directories.
Click to hide internal directories.