Affected by GO-2025-4079
and 3 other vulnerabilities
GO-2025-4079: Silver has unrestricted traffic between Wireguard clients in github.com/bishopfox/sliver
GO-2026-4445: Sliver Vulnerable to Website Path Traversal / Arbitrary File Read (Authenticated) in github.com/bishopfox/sliver
GO-2026-4466: Sliver has DNS C2 OTP Bypass that Allows Unauthenticated Session Flooding and Denial of Service in github.com/bishopfox/sliver
GO-2026-4548: Sliver has Potential Zip Bomb Denial of Service in GzipEncoder in github.com/bishopfox/sliver
package
Version:
v1.1.1
Opens a new window with list of versions in this module.
Published: Nov 18, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetSystemShellPath - Find bash or sh
Shell - Struct to hold shell related data
StartInteractive - Start a shell
func (s *Shell) StartAndWait()
StartAndWait starts a system shell then waits for it to complete
Source Files
¶
Directories
¶
Package pty provides functions for working with Unix terminals.
|
Package pty provides functions for working with Unix terminals. |
Click to show internal directories.
Click to hide internal directories.